#!/usr/bin/python

import os
from os import path
import ujson
import sys

from edge import eventlog
from edge.admin import ui_types
from edge.admin.reply_helpers import *
from edge.com.fs import ln_schema

_BASE_UI_SCHEMA_DIR = '/etc/edge/setupstore/schemas'
_BASE_UI_JNODE_DIR = '/etc/edge/setupstore/admin/actions'


def _run(query_args):
    """
    :type query_args: ui_types.UiQueryArgs
    :rtype: Reply
    """
    # Dispatch http-method.
    if query_args.http_method == 'GET':
        schema_path = path.join(_BASE_UI_SCHEMA_DIR, *query_args.path_info)
        if not (os.path.islink(schema_path) and os.path.exists(os.readlink(schema_path))):
            jnode_path = path.join(_BASE_UI_JNODE_DIR, *query_args.path_info)
            if os.path.exists(jnode_path):
                ln_schema(schema_path, jnode_path)
            else:
                eventlog.log_d('fail: %s not found' % jnode_path)
                return Reply(REPLY_NOT_FOUND_404)

        try:
            with open(schema_path, 'r') as json_file:
                schema_jnode = ujson.load(json_file)
                if schema_jnode:
                    return Reply(REPLY_SUCCESS_200, schema_jnode)

                else:
                    eventlog.log_d("fail: load schema")
                    return Reply(REPLY_NOT_FOUND_404)

        except (IOError, ValueError) as x:
            eventlog.log_d("fail: (%s)" % x.message)
            return Reply(REPLY_INTERNAL_SERVER_ERROR_500)

    else:
        eventlog.log_d('fail: method (%s) not allowed' % query_args.http_method)
        return Reply(REPLY_METHOD_NOT_ALLOWED_405)


def _main():
    exit_code = 1
    eventlog.open_log('cgi-schema', 'debug')
    # noinspection PyBroadException
    try:
        query_args = ui_types.UiQueryArgs.deserialize()

        reply = _run(query_args)
        reply.send()
        exit_code = 0
    except Exception:
        eventlog.log_x()
    finally:
        eventlog.close_log()

    sys.exit(exit_code)


if __name__ == '__main__':
    _main()
