from edge.com.db import DbArgs
from edge.model.types import Location


class TlServiceArgs:
    def __init__(self, endpoint, tl_ident):
        """
        :type endpoint: str
        :type tl_ident: int
        """
        self.endpoint = endpoint
        self.tl_ident = tl_ident


class VsServiceArgs:
    def __init__(self, store, chan='0', log_level='info'):
        """
        :type store: int
        :type chan: str
        :type log_level: str
        """
        self.store = store
        self.chan = chan
        self.log_level = log_level


class BsServiceArgs:
    def __init__(self, sender_to_chan_map, log_level):
        """
        :type sender_to_chan_map: dict [Identity, str | dict [str, str]]
        :type log_level: str
        """
        self.sender_to_chan_map = sender_to_chan_map
        self.log_level = log_level


class AboutServiceArgs:
    def __init__(self, uuid, time, location):
        """
        :type uuid: str
        :type time: str
        :type location: Location
        """
        self.uuid = uuid
        self.time = time
        self.location = location


class RaasServiceArgs:
    def __init__(self, raas_host, raas_port, raas_user, raas_pass):
        """
        :type raas_host: str
        :type raas_port: str
        :type raas_user str
        :type raas_pass: str
        """
        self.raas_host = raas_host
        self.raas_port = raas_port
        self.raas_user = raas_user
        self.raas_pass = raas_pass


class EventQueueArgs:
    def __init__(self, endpoint, min_file_count, max_file_count):
        """
        :type endpoint: str
        :type min_file_count: int
        :type max_file_count: int
        """
        self.endpoint = endpoint
        self.min_file_count = min_file_count
        self.max_file_count = max_file_count


class EventServiceArgs:
    def __init__(self, require_plate, json_queue_list):
        """
        :type require_plate: bool
        :type json_queue_list: list of EventQueueArgs
        """
        self.require_plate = require_plate
        self.json_queue_list = json_queue_list


class ReactServiceArgs:
    def __init__(self, react_endpoint):
        """
        :type react_endpoint: str
        """
        self.react_endpoint = react_endpoint


class TrainerServiceArgs:
    def __init__(self, root_dir, lanes, min_time, max_time, min_file_count, max_file_count):
        """
        :type root_dir: str
        :type min_time: datetime.time
        :type max_time: datetime.time
        :type lanes: list[str]
        :type min_file_count: int
        :type max_file_count: int
        """
        self.root_dir = root_dir
        self.min_time = min_time
        self.max_time = max_time
        self.lanes = lanes
        self.min_file_count = min_file_count
        self.max_file_count = max_file_count


class StatServiceArgs:
    def __init__(self, stat_filepath, stat_tout_sec):
        """
        :type stat_filepath: str
        :type stat_tout_sec: int
        """
        self.stat_filepath = stat_filepath
        self.stat_tout_sec = stat_tout_sec


class LaneDetectorServiceArgs:
    def __init__(self, id_to_lane_list, (im_width, im_height)):
        """
        :type id_to_lane_list: list of (str, list of (int, int))
        :type im_width: int
        :type im_height: int
        """
        self.id_to_lane_list = id_to_lane_list
        self.img_width = im_width
        self.img_height = im_height


class DbServiceArgs:
    def __init__(self, origin_id, db_args):
        """
        :type origin_id: int
        :type db_args: DbArgs
        """
        self.origin_id = origin_id
        self.db_args = db_args


class SignServiceArgs:
    def __init__(self, conf_path, log_level='info'):
        """
        :type conf_path: str
        :type log_level: str
        """
        self.conf_path = conf_path
        self.log_level = log_level


class SystestServiceArgs:
    def __init__(self, conf_path):
        """
        :type conf_path: str | None
        """
        self.conf_path = conf_path
